@@ -145,7 +145,7 @@ class Sandbox(SandboxSetup, SandboxApi):
             self._envd_version = None
             self._envd_access_token = None
         elif sandbox_id is not None:
-            response = SandboxApi.get_info(sandbox_id)
+            response = SandboxApi.get_info(sandbox_id=sandbox_id, api_key=api_key, domain=domain)
 
             self._sandbox_id = sandbox_id
             self._envd_version = response.envd_version
@@ -155,6 +155,27 @@ class Sandbox(SandboxSetup, SandboxApi):
                     response._envd_access_token, Unset
             ):
                 connection_headers["X-Access-Token"] = response._envd_access_token
+
+            # ssh info
+            ssh_info = SandboxApi._get_ssh(
+                sandbox_id=self._sandbox_id,
+                api_key=api_key,
+                domain=domain,
+                debug=debug,
+                request_timeout=request_timeout,
+                proxy=proxy,
+            )
+            print("ssh_info:", ssh_info)
+            # Parse SSH connection details from the connect command
+            pattern = r'ssh\s+-p\s+(\d+).*?\s+([^@\s]+)@([\w\.-]+)'
+            ssh_match = re.search(pattern, ssh_info.connect_command)
+            if ssh_match:
+                self._ssh_port = int(ssh_match.group(1))
+                self._ssh_username = ssh_match.group(2)
+                self._ssh_host = ssh_match.group(3)
+                self._ssh_password = ssh_info.auth_password
+            else:
+                raise Exception("Could not parse SSH connection details")
         else:
             template = template or self.default_template
             timeout = timeout or self.default_sandbox_timeout
